pub struct Options {Show 17 fields
pub max_pending_message_bundles: usize,
pub max_block_limit_errors: u32,
pub staging_bundles_time_budget: Option<Duration>,
pub message_policy: MessagePolicy,
pub priority_bundle_origins: HashSet<ChainId>,
pub cross_chain_message_delivery: CrossChainMessageDelivery,
pub quorum_grace_period: f64,
pub blob_download_timeout: Duration,
pub certificate_batch_download_timeout: Duration,
pub certificate_download_batch_size: u64,
pub certificate_upload_batch_size: u64,
pub sender_certificate_download_batch_size: usize,
pub max_joined_tasks: usize,
pub allow_fast_blocks: bool,
pub notification_circuit_breaker_initial_probe_interval: Duration,
pub notification_circuit_breaker_max_probe_interval: Duration,
pub max_event_stream_queries: usize,
}Fields
max_pending_message_bundles: usizeMaximum number of pending message bundles processed at a time in a block.
max_block_limit_errors: u32Maximum number of message bundles to discard from a block proposal due to block limit errors before discarding all remaining bundles.
Discarded bundles can be retried in the next block.
staging_bundles_time_budget: Option<Duration>Time budget for staging message bundles. When set, limits bundle execution by
wall-clock time, in addition to the count limit from max_pending_message_bundles.
message_policy: MessagePolicyThe policy for automatically handling incoming messages.
priority_bundle_origins: HashSet<ChainId>Chain IDs whose incoming bundles should be processed first when proposing a block.
cross_chain_message_delivery: CrossChainMessageDeliveryWhether to block on cross-chain message delivery.
quorum_grace_period: f64An additional delay, after reaching a quorum, to wait for additional validator signatures, as a fraction of time taken to reach quorum.
blob_download_timeout: DurationThe delay when downloading a blob, after which we try a second validator.
certificate_batch_download_timeout: DurationThe delay when downloading a batch of certificates, after which we try a second validator.
certificate_download_batch_size: u64Maximum number of certificates that we download at a time from one validator when synchronizing one of our chains.
certificate_upload_batch_size: u64Maximum number of certificates read from local storage and uploaded to a validator at a time when synchronizing a chain.
sender_certificate_download_batch_size: usizeMaximum number of sender certificates we try to download and receive in one go when syncing sender chains.
max_joined_tasks: usizeMaximum number of tasks that can be joined concurrently using buffer_unordered.
allow_fast_blocks: boolWhether to allow creating blocks in the fast round. Fast blocks have lower latency but must be used carefully so that there are never any conflicting fast block proposals.
notification_circuit_breaker_initial_probe_interval: DurationInitial probe interval for the notification circuit breaker. When a validator’s notification stream exhausts retries, the circuit breaker waits this long before probing again. Doubles on each failed probe.
notification_circuit_breaker_max_probe_interval: DurationMaximum probe interval for the notification circuit breaker. The probe interval doubles on each failure but is capped at this value.
max_event_stream_queries: usizeMaximum number of event stream IDs to include in a single PreviousEventBlocks
request. Larger sets are split into multiple requests.
Implementations
Sourceimpl Options
impl Options
pub fn test_default() -> Self
Sourceimpl Options
impl Options
Sourcepub fn bundle_execution_policy(&self) -> BundleExecutionPolicy
pub fn bundle_execution_policy(&self) -> BundleExecutionPolicy
Builds the BundleExecutionPolicy based on the client options.